import sys
from pathlib import Path

# 현재 파일의 부모 디렉터리를 경로에 추가
base_path = Path(__file__).resolve().parent.parent
sys.path.append(str(base_path))

import requests
from config.settings import API_KEY, API_SECRET, BASE_URL, GRANT_TYPE

def get_access_token():
    url = f"{BASE_URL}/oauth2/tokenP"
    headers = {
        "content-type": "application/json"
    }
    payload = {
        "grant_type": GRANT_TYPE,
        "appkey": API_KEY,
        "appsecret": API_SECRET
    }
    print("Request URL:", url)
    print("Request Headers:", headers)
    print("Request Payload:", payload)

    response = requests.post(url, headers=headers, json=payload)
    data = response.json()
    
    # 응답 내용 출력 (디버깅용)
    print("Response data:", data)
    
    if 'access_token' in data:
        return data['access_token']
    elif 'error_description' in data:
        raise Exception(f"Error: {data['error_description']}")
    else:
        raise KeyError("Key 'access_token' not found in response")

# Example usage
if __name__ == "__main__":
    try:
        token = get_access_token()
        print(f"Access Token: {token}")
    except Exception as e:
        print(f"Exception: {e}")
