# data/data_collector.py

import sys
from pathlib import Path

# 현재 파일의 부모 디렉터리를 경로에 추가
base_path = Path(__file__).resolve().parent.parent
sys.path.append(str(base_path))

print("sys.path:", sys.path)  # 디버깅용 코드

try:
    import requests
    import pandas as pd
    from config.settings import BASE_URL, API_KEY, API_SECRET, ACCESS_TOKEN
    from config.token_manager import get_access_token
except ImportError as e:
    print("ImportError:", e)  # 디버깅용 코드

def get_stock_price(stock_code):
    global ACCESS_TOKEN
    if ACCESS_TOKEN is None:
        ACCESS_TOKEN = get_access_token()
        
    url = f"{BASE_URL}/uapi/domestic-stock/v1/quotations/inquire-price"
    headers = {
        "Content-Type": "application/json",
        "authorization": f"Bearer {ACCESS_TOKEN}",
        "appKey": API_KEY,
        "appSecret": API_SECRET,
    }
    params = {
        "FID_COND_MRKT_DIV_CODE": "J",
        "FID_INPUT_ISCD": stock_code
    }
    response = requests.get(url, headers=headers, params=params)
    data = response.json()
    
    # 응답 내용 출력 (디버깅용)
    print("Response data:", data)
    
    if 'output' in data:
        return pd.DataFrame([data['output']])
    else:
        raise KeyError("Key 'output' not found in response")

# Example usage
if __name__ == "__main__":
    stock_code = "005930"  # 삼성전자
    try:
        df = get_stock_price(stock_code)
        print(df)
    except Exception as e:
        print(f"Exception: {e}")
