# main.py

import sys
from pathlib import Path

# 현재 파일의 부모 디렉터리를 경로에 추가
base_path = Path(__file__).resolve().parent
sys.path.append(str(base_path))

print("sys.path:", sys.path)  # 디버깅용 코드

try:
    from data.data_collector import get_stock_price
    from strategy.trading_strategy import moving_average_strategy
    from execution.order_executor import place_order
    from risk_management.risk_manager import monitor_trading
    from config.token_manager import get_access_token
    from config.settings import ACCESS_TOKEN
except ImportError as e:
    print("ImportError:", e)  # 디버깅용 코드

def main():
    global ACCESS_TOKEN
    ACCESS_TOKEN = get_access_token()
    
    stock_code = "005930"  # 삼성전자
    data = get_stock_price(stock_code)
    signals = moving_average_strategy(data)
    
    # Example of placing an order based on signals
    for i, signal in signals.iterrows():
        if signal['positions'] == 1:
            place_order(stock_code, 10, signal['Close'], "02")  # 매수
        elif signal['positions'] == -1:
            place_order(stock_code, 10, signal['Close'], "01")  # 매도

    # Start risk monitoring
    monitor_trading()

if __name__ == "__main__":
    main()
